"use strict";

angular.module('stigv1.factory.cardhelper', []).factory('cardHelper', initFactory);

function initFactory ($document, $timeout) {
	return {
		animationFly: function (el, cards, e) {
			if (!el || el === null) {
				return;
			}

			var parentWidth = el.parentNode.offsetWidth,
				width = el.offsetWidth;

			var isGestureSwipe = (typeof e === "object");

			var swipeRight = isGestureSwipe ? this.x > 0 : e === "right";

			this.updateIndex($document[0].getElementsByTagName('td-card'));

			var card = $document[0].getElementsByTagName('td-card')[1];
			this.bringCardUp(card, 0, 0, 0);

			var angle, targetX, targetY, velocityX, rotateTo;

			if (swipeRight) {
				targetX = (parentWidth / 2) + (width);
			} else {
				targetX = -(parentWidth + width);
			}

			if (isGestureSwipe) {
				angle = Math.atan(e.gesture.deltaX / e.gesture.deltaY);
				// Target Y is just the "opposite" side
				targetY = targetX / Math.tan(angle);
				velocityX = e.gesture.velocityX;
				rotateTo = this.rotationAngle;
			} else {
				angle = -1.5;
				targetY = 100;
				velocityX = 0.5;
				rotateTo = -0.2;
			}

			var duration = 0.3 - Math.min(Math.max(Math.abs(velocityX) / 10, 0.05), 0.2);

			ionic.requestAnimationFrame(function () {
				el.style.transform = el.style.webkitTransform = 'translate3d(' + targetX + 'px, ' + targetY + 'px,0) rotate(' + rotateTo + 'rad)';
				el.style.transition = el.style.webkitTransition = 'all ' + duration + 's ease-in-out';
			});

			// Trigger destroy after card has swiped out
			$timeout(function () {
				cards.splice(0, 1);
			});
		},
		updateIndex: function (cards) {
			if (!cards || cards === null) {
				return;
			}

			for (var i = 1; i < cards.length; i++) {
				cards[i].currentIndex -= 1;
			}
		},
		bringCardUp: function (card) {
			card.style.transform = card.style.webkitTransform = 'translate3d(0, ' + 0 + 'px, 0) scale(' + 1 + ')';
		}
	}
}