"use strict";

angular.module('stigv1.services.fblogin', [])


    .service('FbLoginService', function ($rootScope, $ionicLoading, $q, User, $ionicHistory, $window, $location, Config, $log, $ionicContentBanner) {

        "ngInject";

        var vm = this;

        vm.signIn = facebookSignIn;


        // ------------- Private Methods ------------- //

        // This is the success callback from the login method
        var fbLoginSuccess = function (response) {


            console.log('#bfLoginSuccess');
            console.log(response);


            if (! response.authResponse) {
                fbLoginError();
                $ionicLoading.hide();
                return;
            } else {

                getFacebookProfileInfo(response.authResponse)
                    .then(function (profileInfo) {
                        profileInfo.uid = profileInfo.id;
                        profileInfo.provider = "facebook";

                        $window.localStorage.setItem('_login_provider', profileInfo.provider);


                        console.log("#### ON EMIT LE LOGIN  Facebook C'EST PARTI !");

                        var success = {status:'connected',authResponse:response.authResponse};

                        $rootScope.$emit('event:social-sign-in-success', {login: success, profile: profileInfo});

                    }, function (fail) {
                        // Fail get profile info
                        $ionicLoading.hide();
                        $log.error('profile info fail', fail);
                    });



            }


        };

        // This is the fail callback from the login method
        var fbLoginError = function (error) {
            $log.error(error);
            $ionicLoading.hide();
            displayErrorBanner("Une erreur est survenue...");
        };

        // This method is to get the user profile info from the facebook api
        var getFacebookProfileInfo = function (authResponse) {
            var info = $q.defer();

            facebookConnectPlugin.api('/me?fields=email,name&access_token=' + authResponse.accessToken, null,
                function (response) {
                    info.resolve(response);
                },
                function (response) {
                    info.reject(response);
                }
            );
            return info.promise;
        };

        // --------------------------------------- //


        // Public function (Launch signIn fb)
        function facebookSignIn () {

            facebookConnectPlugin.getLoginStatus(function (success) {
                if (success.status === 'connected') {

                    // Check if we have our user saved
                    var user = User.getId();

                    if (! user) {
                        getFacebookProfileInfo(success.authResponse)
                            .then(function (profileInfo) {
                                profileInfo.uid = profileInfo.id;
                                profileInfo.provider = "facebook";

                                $window.localStorage.setItem('_login_provider', profileInfo.provider);

                                $rootScope.$emit('event:social-sign-in-success', {login: success, profile: profileInfo});
                            }, function (fail) {
                                // Fail get profile info
                                $log.error('profile info fail', fail);
                            });
                    } else {
                        if ($rootScope.redirect && $rootScope.redirect.length > 0) {

                            console.warn("On demande redirect à " + $rootScope.redirect);

                            $location.path($rootScope.redirect + '');


                            $window.location.reload();

                            $rootScope.redirect = null;
                            delete $rootScope.redirect;

                        } else {

                            $ionicHistory.nextViewOptions({
                                disableBack: true,
                                disableAnimate: true
                            });

                            $window.location.reload();

                        }

                        Config.updateTownName();
                    }
                } else {
                    // If (success.status === 'not_authorized') the user is logged in to Facebook,
                    // but has not authenticated your app
                    // Else the person is not logged into Facebook,
                    // so we're not sure if they are logged into this app or not.

                    console.log('getLoginStatus', success);

                    // Ask the permissions you need. You can learn more about
                    // FB permissions here: https://developers.facebook.com/docs/facebook-login/permissions/v2.4
                    facebookConnectPlugin.login(['email', 'public_profile'], fbLoginSuccess, fbLoginError);
                }
            }, function (err) {
                fbLoginError();
            });

        }

        // FIXME create an error service to handle it.
        var displayErrorBanner = function (message) {
            $ionicContentBanner.show({
                text: [message],

                autoClose: 2600,
                type: 'error',
                transition: 'vertical'
            });
        };
    });
